/****************************************************************************
** Meta object code from reading C++ file 'cryptographyeditorbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kidentitymanagement-26.08.0/src/quick/cryptographyeditorbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cryptographyeditorbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24KIdentityManagementQuick25CryptographyEditorBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto KIdentityManagementQuick::CryptographyEditorBackend::qt_create_metaobjectdata<qt_meta_tag_ZN24KIdentityManagementQuick25CryptographyEditorBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KIdentityManagementQuick::CryptographyEditorBackend",
        "cryptographyBackendChanged",
        "",
        "openPgpKeyListModelChanged",
        "smimeKeyListModelChanged",
        "identityChanged",
        "indexForIdentity",
        "QModelIndex",
        "QAbstractItemModel*",
        "model",
        "KIdentityManagementCore::Identity",
        "identity",
        "KIdentityManagementQuick::KeyUseTypes::KeyUse",
        "keyUse",
        "stringFromKeyByteArray",
        "key",
        "openPgpKeyListModel",
        "smimeKeyListModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cryptographyBackendChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openPgpKeyListModelChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'smimeKeyListModelChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'indexForIdentity'
        QtMocHelpers::MethodData<QModelIndex(QAbstractItemModel *, const KIdentityManagementCore::Identity &, const KIdentityManagementQuick::KeyUseTypes::KeyUse)>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'stringFromKeyByteArray'
        QtMocHelpers::MethodData<QString(const QByteArray &)>(14, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QByteArray, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'identity'
        QtMocHelpers::PropertyData<KIdentityManagementCore::Identity>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'openPgpKeyListModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(16, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'smimeKeyListModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(17, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CryptographyEditorBackend, qt_meta_tag_ZN24KIdentityManagementQuick25CryptographyEditorBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KIdentityManagementQuick::CryptographyEditorBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KIdentityManagementQuick25CryptographyEditorBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KIdentityManagementQuick25CryptographyEditorBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24KIdentityManagementQuick25CryptographyEditorBackendE_t>.metaTypes,
    nullptr
} };

void KIdentityManagementQuick::CryptographyEditorBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CryptographyEditorBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cryptographyBackendChanged(); break;
        case 1: _t->openPgpKeyListModelChanged(); break;
        case 2: _t->smimeKeyListModelChanged(); break;
        case 3: _t->identityChanged(); break;
        case 4: { QModelIndex _r = _t->indexForIdentity((*reinterpret_cast<std::add_pointer_t<QAbstractItemModel*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIdentityManagementCore::Identity>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KIdentityManagementQuick::KeyUseTypes::KeyUse>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->stringFromKeyByteArray((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIdentityManagementCore::Identity >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractItemModel* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CryptographyEditorBackend::*)()>(_a, &CryptographyEditorBackend::cryptographyBackendChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CryptographyEditorBackend::*)()>(_a, &CryptographyEditorBackend::openPgpKeyListModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CryptographyEditorBackend::*)()>(_a, &CryptographyEditorBackend::smimeKeyListModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CryptographyEditorBackend::*)()>(_a, &CryptographyEditorBackend::identityChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KIdentityManagementCore::Identity >(); break;
        case 2:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KIdentityManagementCore::Identity*>(_v) = _t->identity(); break;
        case 1: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->openPgpKeyListModel(); break;
        case 2: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->smimeKeyListModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIdentity(*reinterpret_cast<KIdentityManagementCore::Identity*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KIdentityManagementQuick::CryptographyEditorBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIdentityManagementQuick::CryptographyEditorBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KIdentityManagementQuick25CryptographyEditorBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KIdentityManagementQuick::CryptographyEditorBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KIdentityManagementQuick::CryptographyEditorBackend::cryptographyBackendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KIdentityManagementQuick::CryptographyEditorBackend::openPgpKeyListModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KIdentityManagementQuick::CryptographyEditorBackend::smimeKeyListModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KIdentityManagementQuick::CryptographyEditorBackend::identityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
